MatchAction

Enum MatchAction 

pub enum MatchAction {
    None,
    Pop {
        count: usize,
    },
    Push {
        pop_before: usize,
        push: ContextPush,
        with_prototype: Vec<CompiledPattern>,
    },
    Set {
        pop_before: usize,
        set: ContextPush,
        with_prototype: Vec<CompiledPattern>,
    },
    Embed {
        pop_before: usize,
        embed: String,
        embed_scope: Vec<String>,
        escape_source: String,
        escape: Arc<Regex>,
        escape_captures: HashMap<u32, Vec<String>>,
        with_prototype: Vec<CompiledPattern>,
    },
}
Action to apply after a match is found.

Variants



None

No stack action.



Pop

Pop one or more contexts from the stack.

Fields

count: usize

Number of contexts to pop.



Push

Push one or more contexts onto the stack.

Fields

pop_before: usize

Pop this many contexts before pushing.

push: ContextPush

Context(s) to push.

with_prototype: Vec<CompiledPattern>

Prototype patterns applied while the pushed contexts are active.



Set

Replace (set) the current context stack with new contexts.

Fields

pop_before: usize

Pop this many contexts before setting.

set: ContextPush

Context(s) to set (push after popping).

with_prototype: Vec<CompiledPattern>

Prototype patterns applied while the new contexts are active.



Embed

Temporarily embed another syntax until an escape pattern is matched.

Fields

pop_before: usize

Pop this many contexts before entering the embed.

embed: String

The embedded syntax reference.

embed_scope: Vec<String>

Scope(s) applied to the embedded content.

escape_source: String

Original escape regex source string.

escape: Arc<Regex>

Compiled escape regex.

escape_captures: HashMap<u32, Vec<String>>

Per-capture scopes for the escape match.

with_prototype: Vec<CompiledPattern>

Prototype patterns applied while embedded.