pub enum MatchAction {
None,
Pop {
count: usize,
},
Push {
pop_before: usize,
push: ContextPush,
with_prototype: Vec<CompiledPattern>,
},
Set {
pop_before: usize,
set: ContextPush,
with_prototype: Vec<CompiledPattern>,
},
Embed {
pop_before: usize,
embed: String,
embed_scope: Vec<String>,
escape_source: String,
escape: Arc<Regex>,
escape_captures: HashMap<u32, Vec<String>>,
with_prototype: Vec<CompiledPattern>,
},
}Expand description
Action to apply after a match is found.
Variants
None
No stack action.
Pop
Pop one or more contexts from the stack.
Push
Push one or more contexts onto the stack.
Fields

push: ContextPushContext(s) to push.

with_prototype: Vec<CompiledPattern>Prototype patterns applied while the pushed contexts are active.
Set
Replace (set) the current context stack with new contexts.
Fields

set: ContextPushContext(s) to set (push after popping).

with_prototype: Vec<CompiledPattern>Prototype patterns applied while the new contexts are active.
Embed
Temporarily embed another syntax until an escape pattern is matched.
Fields

with_prototype: Vec<CompiledPattern>Prototype patterns applied while embedded.